word_list = [
 'aback', 'abase', 'abate', 'abhor', 'abode', 'abort', 'about', 'above', 'abuse', 'abyss',
 'ached', 'acids', 'acorn', 'acres', 'acrid', 'actin', 'actor', 'acute', 'adage', 'adapt',
 'added', 'adder', 'addle', 'adept', 'adieu', 'adlib', 'admin', 'admit', 'adobe', 'adopt',
 'adore', 'adorn', 'adult', 'aeons', 'affix', 'afire', 'afoot', 'afore', 'afoul', 'after',
 'again', 'agape', 'agate', 'agent', 'agile', 'aging', 'aglow', 'agony', 'agree', 'ahead',
 'aided', 'aider', 'aimer', 'aisle', 'alamo', 'alarm', 'album', 'alder', 'aleph', 'alert',
 'algae', 'algal', 'algas', 'alias', 'alibi', 'alien', 'align', 'alike', 'alive', 'allay',
 'alley', 'allot', 'allow', 'alloy', 'aloes', 'aloft', 'alone', 'along', 'aloof', 'aloud',
 'alpha', 'altar', 'alter', 'altos', 'amass', 'amaze', 'amber', 'amble', 'amend', 'amino',
 'amiss', 'amity', 'among', 'amped', 'ample', 'amply', 'amuse', 'angel', 'anger', 'angle',
 'angry', 'angst', 'anile', 'anime', 'anise', 'ankle', 'annex', 'annoy', 'annul', 'anode',
 'antic', 'anvil', 'aorta', 'apace', 'apart', 'aphid', 'aping', 'apnea', 'apple', 'apply',
 'apron', 'arbor', 'arced', 'ardor', 'areas', 'arena', 'argue', 'arise', 'armed', 'armor',
 'aroma', 'arose', 'arras', 'array', 'arrow', 'arson', 'artsy', 'ascot', 'ashen', 'asian',
 'aside', 'asked', 'askew', 'aspen', 'assay', 'asses', 'asset', 'aster', 'atlas', 'atoll',
 'atoms', 'atone', 'attic', 'audio', 'audit', 'auger', 'aught', 'augur', 'aunty', 'aural',
 'autos', 'avail', 'avant', 'avert', 'avian', 'avoid', 'await', 'awake', 'award', 'aware',
 'awash', 'awful', 'awoke', 'axiom', 'axion', 'azure', 'bacon', 'badge', 'badly', 'bagel',
 'baker', 'baler', 'balky', 'balmy', 'banal', 'banjo', 'barge', 'barmy', 'baron', 'basal',
 'based', 'basic', 'basil', 'basin', 'basis', 'baste', 'batch', 'bathe', 'beach', 'beads',
 'beady', 'beard', 'bears', 'beast', 'beats', 'beech', 'beefy', 'befit', 'began', 'begat',
 'beget', 'begin', 'begun', 'being', 'belch', 'belie', 'belle', 'belly', 'below', 'bench',
 'beret', 'berry', 'berth', 'beset', 'betas', 'bevel', 'bezel', 'bicep', 'biddy', 'bigot',
 'bilge', 'billy', 'binge', 'bingo', 'biome', 'birch', 'birds', 'birth', 'bison', 'biter',
 'bites', 'black', 'blade', 'blame', 'bland', 'blank', 'blare', 'blast', 'blaze', 'bleak',
 'bleat', 'blend', 'bless', 'blimp', 'blind', 'blink', 'blitz', 'block', 'blood', 'bloom',
 'blown', 'blues', 'bluff', 'blunt', 'blush', 'board', 'boats', 'bobby', 'bones', 'bongo',
 'books', 'boost', 'booth', 'boots', 'borne', 'bound', 'boxes', 'brace', 'brain', 'brake',
 'brand', 'brash', 'brave', 'bravo', 'bread', 'break', 'breed', 'briar', 'brick', 'brief',
 'brine', 'bring', 'brink', 'briny', 'brisk', 'broad', 'broil', 'broke', 'brood', 'brown',
 'brunt', 'brush', 'build', 'built', 'bumpy', 'burnt', 'buyer', 'buzzy', 'bylaw', 'cabal',
 'cable', 'cacao', 'cache', 'cacti', 'caddy', 'cadet', 'cagey', 'cairn', 'calif', 'calls',
 'camel', 'cameo', 'camps', 'canal', 'candy', 'canoe', 'canon', 'caper', 'caput', 'carat',
 'cards', 'carey', 'cargo', 'carlo', 'carol', 'carry', 'carte', 'carve', 'cases', 'caste',
 'casts', 'catch', 'cater', 'catty', 'caulk', 'cause', 'cells', 'cents', 'chafe', 'chain',
 'chair', 'champ', 'chant', 'chaos', 'chard', 'charm', 'chart', 'chase', 'chasm', 'cheap',
 'cheat', 'check', 'cheek', 'cheer', 'chess', 'chest', 'chick', 'chide', 'chief', 'child',
 'chili', 'chill', 'chime', 'chimp', 'china', 'chirp', 'chock', 'choir', 'choke', 'chomp',
 'chord', 'chore', 'chose', 'chris', 'chuck', 'chump', 'chunk', 'churn', 'chute', 'cider',
 'cigar', 'cinch', 'circa', 'civic', 'civil', 'clack', 'claim', 'clamp', 'clash', 'class',
 'clave', 'clean', 'clear', 'cleft', 'click', 'cliff', 'climb', 'cling', 'clink', 'clock',
 'clomp', 'close', 'cloth', 'cloud', 'clout', 'coach', 'coast', 'cocoa', 'codes', 'coins',
 'color', 'combo', 'comes', 'comfy', 'comic', 'comma', 'conch', 'conga', 'coopt', 'coral',
 'corps', 'costs', 'couch', 'cough', 'could', 'count', 'court', 'couth', 'coven', 'coyly',
 'craft', 'cramp', 'crane', 'crank', 'crash', 'crass', 'crate', 'crave', 'cream', 'creek',
 'creme', 'crick', 'crime', 'crimp', 'crisp', 'croup', 'crowd', 'crown', 'crude', 'crumb',
 'crush', 'crypt', 'cubit', 'cumin', 'cupid', 'curse', 'curso', 'curve', 'cycle', 'cynic',
 'daily', 'dairy', 'daisy', 'dance', 'dated', 'daunt', 'dazed', 'deals', 'dealt', 'death',
 'debar', 'debit', 'debut', 'decaf', 'decay', 'decor', 'decoy', 'decry', 'dedup', 'defer',
 'delay', 'delta', 'demon', 'demur', 'denim', 'dense', 'depal', 'depot', 'depth', 'derby',
 'deter', 'detox', 'deuce', 'devil', 'diary', 'diced', 'digit', 'dilly', 'dimly', 'diner',
 'dingo', 'dingy', 'diode', 'dirge', 'dirty', 'disco', 'ditch', 'ditto', 'ditty', 'diver',
 'dizzy', 'dodge', 'dodgy', 'doggy', 'dogma', 'doing', 'donor', 'doors', 'doubt', 'dowel',
 'dozed', 'dozen', 'draft', 'drama', 'drank', 'drape', 'drawn', 'dread', 'dream', 'dress',
 'dried', 'drill', 'drink', 'drive', 'droll', 'drone', 'drops', 'drove', 'drown', 'drugs',
 'druid', 'drums', 'drunk', 'ducks', 'dully', 'dummy', 'dusty', 'dwarf', 'dweeb', 'dying',
 'eager', 'eagle', 'early', 'earst', 'earth', 'easel', 'eaten', 'eater', 'ebony', 'edges',
 'edict', 'edify', 'eerie', 'egret', 'eight', 'eject', 'elbow', 'elder', 'elect', 'elegy',
 'elfin', 'elide', 'elite', 'elope', 'elude', 'email', 'embed', 'ember', 'emcee', 'empty',
 'enact', 'endow', 'enema', 'enemy', 'enjoy', 'ennui', 'ensue', 'enter', 'entry', 'envoy',
 'epoch', 'epoxy', 'equal', 'equip', 'erase', 'erect', 'erode', 'error', 'erupt', 'essay',
 'ester', 'ether', 'ethic', 'evade', 'evans', 'event', 'every', 'evict', 'evoke', 'exact',
 'exalt', 'excel', 'exert', 'exile', 'exist', 'exits', 'expel', 'extol', 'extra', 'fable',
 'faced', 'faces', 'facet', 'facts', 'fails', 'faint', 'fairy', 'faith', 'falls', 'false',
 'fancy', 'farce', 'farms', 'fatal', 'fatty', 'fault', 'fauna', 'favor', 'feast', 'fecal',
 'feign', 'femme', 'femur', 'fence', 'fetal', 'fetch', 'fetid', 'fever', 'fewer', 'fiber',
 'ficus', 'field', 'fiend', 'fifer', 'fifth', 'fifty', 'fight', 'filed', 'files', 'filet',
 'filly', 'films', 'filmy', 'filth', 'final', 'finch', 'finer', 'fires', 'firms', 'first',
 'fishy', 'fixed', 'fixer', 'fizzy', 'fjord', 'flack', 'flags', 'flail', 'flair', 'flake',
 'flame', 'flank', 'flare', 'flash', 'flask', 'fleck', 'fleet', 'flesh', 'flick', 'flier',
 'flies', 'fling', 'flint', 'flirt', 'float', 'flock', 'flood', 'floor', 'flora', 'floss',
 'flour', 'flout', 'flown', 'flows', 'fluff', 'fluid', 'fluke', 'flume', 'flush', 'flute',
 'foamy', 'focal', 'focus', 'foggy', 'foist', 'folio', 'folks', 'folly', 'fonts', 'foods',
 'foray', 'force', 'forge', 'forgo', 'forms', 'forte', 'forth', 'forty', 'forum', 'found',
 'foyer', 'frail', 'frame', 'frank', 'fraud', 'freak', 'freed', 'freer', 'fresh', 'friar',
 'fried', 'frill', 'frisk', 'fritz', 'frock', 'front', 'frost', 'froth', 'frown', 'froze',
 'fruit', 'fudge', 'fugue', 'fully', 'funds', 'fungi', 'funky', 'funny', 'furry', 'fussy',
 'fuzzy', 'gamer', 'gamma', 'gassy', 'gates', 'gauge', 'gavel', 'gawky', 'gazer', 'gecko',
 'geeky', 'geese', 'genes', 'genre', 'ghost', 'ghoul', 'giant', 'giddy', 'gifts', 'gipsy',
 'girls', 'girly', 'given', 'giver', 'gives', 'gizmo', 'glade', 'gland', 'glare', 'glass',
 'glaze', 'gleam', 'glean', 'glide', 'glint', 'glitz', 'gloat', 'globe', 'gloom', 'glory',
 'gloss', 'glove', 'glyph', 'gnash', 'gnome', 'goals', 'godly', 'going', 'golem', 'golly',
 'gonad', 'goods', 'goody', 'gooey', 'goose', 'gorge', 'gouge', 'grace', 'grade', 'graft',
 'grail', 'grain', 'grand', 'grant', 'grape', 'graph', 'grasp', 'grass', 'grate', 'grave',
 'gravy', 'great', 'greed', 'green', 'greet', 'grief', 'grift', 'grill', 'grime', 'grimy',
 'grind', 'gripe', 'groan', 'groin', 'groom', 'grope', 'gross', 'group', 'grout', 'grove',
 'growl', 'grown', 'grows', 'gruff', 'grump', 'grunt', 'guano', 'guard', 'guava', 'guess',
 'guest', 'guide', 'guild', 'guile', 'guilt', 'guise', 'gulch', 'gully', 'gumbo', 'guppy',
 'gusto', 'gusty', 'gypsy', 'habit', 'hairy', 'halve', 'hands', 'handy', 'hangs', 'happy',
 'hardy', 'harem', 'harpy', 'harry', 'harsh', 'haste', 'hasty', 'hatch', 'hater', 'haunt',
 'haven', 'hazel', 'heads', 'heady', 'heard', 'heart', 'heath', 'heave', 'heavy', 'hedge',
 'hedon', 'hefty', 'heist', 'helen', 'helix', 'hello', 'helps', 'hence', 'henry', 'heron',
 'hills', 'hilly', 'hinge', 'hints', 'hippy', 'hired', 'hitch', 'hoard', 'hobby', 'hoist',
 'holds', 'holes', 'holly', 'homer', 'homes', 'honey', 'honor', 'hoped', 'hopes', 'horde',
 'horny', 'horse', 'hosts', 'hotel', 'hound', 'hours', 'house', 'hovel', 'hover', 'howdy',
 'huffy', 'human', 'humid', 'humor', 'humph', 'hunch', 'hunky', 'hurry', 'husky', 'hyena',
 'hymen', 'icily', 'icing', 'ideal', 'ideas', 'image', 'inane', 'inbox', 'index', 'india',
 'inert', 'inlay', 'inner', 'input', 'irony', 'issue', 'items', 'ivory', 'jaded', 'james',
 'janky', 'japan', 'jazzy', 'jeans', 'jelly', 'jenny', 'jerry', 'jesse', 'jewel', 'jiffy',
 'jimmy', 'jived', 'johns', 'joins', 'joint', 'joker', 'jolly', 'jones', 'joust', 'judge',
 'judgy', 'juice', 'jumbo', 'jumpy', 'junky', 'kappa', 'karma', 'kayak', 'keeps', 'kelly',
 'kings', 'kiosk', 'knack', 'known', 'knows', 'koala', 'label', 'lacks', 'ladle', 'lakes',
 'lance', 'lands', 'lanes', 'laped', 'lapse', 'large', 'laser', 'latch', 'later', 'lathe',
 'laugh', 'laura', 'layer', 'leach', 'leads', 'leapt', 'learn', 'lease', 'leash', 'least',
 'leave', 'leeds', 'leery', 'lefty', 'legal', 'lemon', 'lemur', 'level', 'lever', 'lewis',
 'libel', 'light', 'liked', 'liken', 'likes', 'lilac', 'limbo', 'limit', 'lined', 'lines',
 'lingo', 'links', 'lions', 'lists', 'lithe', 'lived', 'liver', 'lives', 'livid', 'loads',
 'loans', 'lobby', 'local', 'locks', 'lodge', 'logic', 'logos', 'looks', 'loops', 'loopy',
 'loose', 'lords', 'loser', 'loses', 'lousy', 'loved', 'lover', 'loves', 'lower', 'loyal',
 'lucid', 'lucky', 'lumen', 'lunar', 'lunch', 'lurid', 'lying', 'macho', 'macro', 'magic',
 'magma', 'major', 'maker', 'makes', 'males', 'mambo', 'mango', 'manor', 'maple', 'march',
 'maria', 'marie', 'marsh', 'mason', 'masse', 'match', 'mates', 'maths', 'maybe', 'mayor',
 'meals', 'means', 'meant', 'meaty', 'media', 'meets', 'melon', 'menus', 'mercy', 'merge',
 'merit', 'merry', 'messy', 'metal', 'meter', 'metro', 'micro', 'midst', 'might', 'miles',
 'mills', 'mimic', 'mimsy', 'minds', 'mines', 'minor', 'minus', 'mirth', 'miser', 'mixed',
 'mixer', 'mocha', 'modal', 'model', 'modes', 'money', 'month', 'moore', 'moral', 'mossy',
 'motel', 'mothy', 'motto', 'moult', 'mound', 'mount', 'mouse', 'mouth', 'moved', 'moves',
 'movie', 'mucky', 'munch', 'mushy', 'music', 'myrrh', 'nadir', 'named', 'nanny', 'nappy',
 'naval', 'navel', 'needs', 'nerve', 'never', 'newer', 'newly', 'niche', 'night', 'ninja',
 'noble', 'nodes', 'noise', 'north', 'noted', 'notes', 'notre', 'novel', 'nudge', 'nurse',
 'nylon', 'nymph', 'oaken', 'oasis', 'obese', 'occur', 'ocean', 'octal', 'octet', 'offer',
 'often', 'olden', 'older', 'olive', 'omega', 'oomph', 'opens', 'opera', 'opine', 'optic',
 'orate', 'orbit', 'order', 'organ', 'other', 'otter', 'ought', 'outer', 'ovale', 'owned',
 'owner', 'oxide', 'pacer', 'packs', 'paddy', 'pages', 'paint', 'pairs', 'paled', 'palsy',
 'panda', 'panel', 'panic', 'pants', 'paper', 'parch', 'pares', 'parks', 'parse', 'parts',
 'party', 'pasta', 'paste', 'patch', 'paths', 'patio', 'patsy', 'pause', 'peace', 'peach',
 'peaks', 'pearl', 'pears', 'pedal', 'peers', 'penny', 'perch', 'pesto', 'petal', 'peter',
 'phase', 'phlox', 'phone', 'photo', 'piano', 'picks', 'piece', 'piles', 'pills', 'pilot',
 'pinky', 'pinot', 'pipes', 'pique', 'pitch', 'pithy', 'pivot', 'pixel', 'pixie', 'pizza',
 'place', 'plaid', 'plain', 'plane', 'plank', 'plans', 'plant', 'plate', 'plays', 'plaza',
 'plead', 'pleat', 'plier', 'plots', 'pluck', 'plumb', 'plume', 'plunk', 'plush', 'poems',
 'point', 'poker', 'polar', 'poles', 'polls', 'polyp', 'pools', 'poppy', 'porch', 'ports',
 'posts', 'pouch', 'pound', 'power', 'prank', 'press', 'price', 'pride', 'prime', 'print',
 'prior', 'prism', 'privy', 'prize', 'probe', 'prone', 'proof', 'prose', 'proud', 'prove',
 'proxy', 'prude', 'pudgy', 'puffy', 'pulls', 'pulse', 'pumps', 'punch', 'pupil', 'puppy',
 'purse', 'pushy', 'pylon', 'quack', 'quaff', 'quail', 'quake', 'quant', 'quark', 'quart',
 'quash', 'queen', 'query', 'quest', 'queue', 'quick', 'quiet', 'quill', 'quilt', 'quint',
 'quirk', 'quite', 'quote', 'rabid', 'racer', 'radar', 'radii', 'radio', 'raise', 'rally',
 'ranch', 'range', 'ranks', 'rapid', 'rated', 'rates', 'ratio', 'raven', 'reach', 'react',
 'reads', 'ready', 'realm', 'reaps', 'rebar', 'rebel', 'redux', 'refer', 'refit', 'regal',
 'relax', 'relay', 'relic', 'remit', 'repay', 'repel', 'reply', 'reset', 'resin', 'retro',
 'rhino', 'rhyme', 'rider', 'rides', 'ridge', 'rifle', 'right', 'rings', 'risen', 'rises',
 'risks', 'river', 'rivet', 'roads', 'robin', 'rocks', 'rocky', 'roger', 'rogue', 'roles',
 'rolls', 'roman', 'rooms', 'roots', 'roped', 'roses', 'rouge', 'rough', 'round', 'rouse',
 'route', 'royal', 'rugby', 'ruled', 'ruler', 'rules', 'rumor', 'runny', 'rural', 'saber',
 'sable', 'safer', 'salad', 'sales', 'salon', 'salsa', 'salty', 'sands', 'sandy', 'santa',
 'sassy', 'satin', 'sauce', 'savor', 'scale', 'scant', 'scare', 'scary', 'scene', 'scoff',
 'scone', 'scope', 'score', 'scout', 'scrap', 'screw', 'seats', 'seeds', 'seedy', 'seeks',
 'seems', 'segue', 'sells', 'sends', 'sense', 'serve', 'setup', 'seven', 'sever', 'shade',
 'shady', 'shaft', 'shake', 'shall', 'shame', 'shank', 'shape', 'shard', 'share', 'shark',
 'sharp', 'shave', 'shear', 'sheep', 'sheet', 'shelf', 'shell', 'shiek', 'shift', 'shine',
 'ships', 'shirt', 'shock', 'shoes', 'shone', 'shoot', 'shops', 'shore', 'shorn', 'short',
 'shout', 'shown', 'shows', 'shrew', 'shuck', 'sides', 'siege', 'sight', 'sigma', 'signs',
 'silly', 'simon', 'since', 'sinch', 'sissy', 'sites', 'sixth', 'sized', 'sizes', 'skill',
 'skins', 'skirt', 'skunk', 'slant', 'slate', 'slave', 'sleek', 'sleep', 'slice', 'slick',
 'slide', 'slime', 'slimy', 'sling', 'sloop', 'slope', 'slosh', 'slots', 'slump', 'slung',
 'smack', 'small', 'smart', 'smash', 'smelt', 'smile', 'smirk', 'smith', 'smoke', 'snack',
 'snake', 'snaky', 'sneak', 'snide', 'snoop', 'snout', 'solar', 'solid', 'solve', 'songs',
 'sonic', 'sorry', 'sorts', 'souls', 'sound', 'south', 'space', 'spade', 'spank', 'spare',
 'spark', 'spasm', 'speak', 'spear', 'speed', 'spend', 'spent', 'spike', 'spilt', 'spine',
 'spiny', 'spire', 'splat', 'splay', 'split', 'spoil', 'spoke', 'spoof', 'spook', 'spool',
 'spore', 'spork', 'sport', 'spots', 'spray', 'spunk', 'spurt', 'squad', 'stack', 'staff',
 'stage', 'stake', 'stale', 'stalk', 'stall', 'stamp', 'stand', 'stank', 'stare', 'stark',
 'stars', 'start', 'stash', 'state', 'stays', 'steal', 'steam', 'steel', 'steep', 'steps',
 'stern', 'steve', 'stick', 'still', 'stilt', 'stink', 'stock', 'stomp', 'stone', 'stood',
 'stool', 'stops', 'store', 'stork', 'storm', 'story', 'stout', 'stove', 'strap', 'stray',
 'strip', 'strut', 'stuck', 'study', 'stuff', 'stunk', 'stunt', 'style', 'sugar', 'suite',
 'suits', 'sunny', 'super', 'surge', 'susan', 'sushi', 'swami', 'swamp', 'swank', 'swarm',
 'swath', 'sweat', 'sweep', 'sweet', 'swell', 'swept', 'swift', 'swing', 'swipe', 'swiss',
 'swoop', 'sword', 'sworn', 'syrup', 'table', 'taboo', 'tacet', 'tacit', 'taken', 'takes',
 'talep', 'tales', 'talks', 'tango', 'tangy', 'tanks', 'taper', 'tapes', 'tapir', 'tarot',
 'tarpa', 'tarry', 'taser', 'tasks', 'taste', 'tasty', 'tatty', 'taunt', 'taupe', 'taxes',
 'teach', 'teams', 'tears', 'teary', 'teeth', 'telex', 'tempo', 'tenet', 'tenor', 'tense',
 'tepee', 'tepid', 'terry', 'terse', 'tests', 'tetra', 'texas', 'texts', 'thank', 'theca',
 'theft', 'their', 'theme', 'there', 'these', 'theta', 'thick', 'thief', 'thine', 'thing',
 'think', 'third', 'thong', 'those', 'three', 'threw', 'throw', 'thrum', 'thumb', 'thump',
 'thyme', 'tibia', 'tidal', 'tiger', 'tight', 'tilde', 'tiles', 'timer', 'times', 'timid',
 'tired', 'tithe', 'title', 'tizzy', 'toady', 'toast', 'today', 'token', 'tommy', 'tonal',
 'tones', 'tonic', 'tools', 'tooth', 'topaz', 'topic', 'torus', 'total', 'touch', 'tough',
 'tours', 'towel', 'tower', 'towns', 'toxic', 'toxin', 'trace', 'track', 'tract', 'tracy',
 'trade', 'trail', 'train', 'trait', 'tramp', 'trans', 'traps', 'trash', 'treat', 'treed',
 'trees', 'trend', 'trial', 'tribe', 'trice', 'trick', 'tried', 'tries', 'trims', 'tripe',
 'trips', 'trite', 'troll', 'troop', 'trove', 'truce', 'truck', 'truly', 'trump', 'trunk',
 'trust', 'truth', 'tryst', 'tuber', 'tubes', 'tudor', 'tulip', 'tulle', 'tulsa', 'tummy',
 'tumor', 'tuned', 'tuner', 'tunic', 'turbo', 'turns', 'tutor', 'tweak', 'tweet', 'twice',
 'twine', 'twins', 'twirl', 'twist', 'tying', 'typed', 'types', 'ultra', 'umbra', 'uncle',
 'under', 'undue', 'union', 'unite', 'units', 'unity', 'untap', 'until', 'unzip', 'upend',
 'upper', 'upset', 'urban', 'urged', 'usage', 'users', 'usher', 'using', 'usual', 'utero',
 'utils', 'utter', 'uvula', 'vague', 'valet', 'valid', 'valor', 'value', 'valve', 'vapid',
 'vapor', 'vault', 'venom', 'venue', 'verde', 'verge', 'verse', 'verve', 'video', 'views',
 'vigor', 'villa', 'vinyl', 'viola', 'virus', 'visit', 'vista', 'vital', 'vivid', 'vixen',
 'vocal', 'voice', 'voila', 'vomit', 'voter', 'votes', 'vouch', 'vowel', 'wages', 'wagon',
 'waist', 'wales', 'walks', 'walls', 'waltz', 'wants', 'waste', 'watch', 'water', 'waves',
 'wayne', 'weary', 'weeks', 'weigh', 'weird', 'wells', 'welsh', 'wench', 'whale', 'wharf',
 'wheat', 'wheel', 'where', 'which', 'whiff', 'while', 'whisk', 'white', 'whole', 'whose',
 'wider', 'widow', 'width', 'wills', 'wines', 'wings', 'wired', 'wires', 'wiser', 'witch',
 'witty', 'woman', 'women', 'woods', 'woody', 'words', 'works', 'world', 'worry', 'worse',
 'worst', 'worth', 'would', 'wound', 'wrath', 'wreak', 'wreck', 'wrist', 'write', 'wrong',
 'wrote', 'xenon', 'yacht', 'yards', 'years', 'yeast', 'yield', 'yogic', 'young', 'yours',
 'youth', 'yummy', 'zappy', 'zebra', 'zesty', 'zilch', 'zippy', 'zonal', 'zoner', 'zones',
]
